import { Resource } from "../rdf/Resource";
import { IComponentFactory } from "./IComponentFactory";
import { Loader } from "../Loader";
/**
 * Factory for component definitions with explicit arguments.
 */
export declare class UnnamedComponentFactory implements IComponentFactory {
    _componentDefinition: any;
    _constructable: boolean;
    _overrideRequireNames: {
        [id: string]: string;
    };
    _componentRunner: Loader;
    constructor(componentDefinition: Resource, constructable: boolean, overrideRequireNames?: {
        [id: string]: string;
    }, componentRunner?: Loader);
    _validateParam(resource: any, field: string, type: string, optional?: boolean): void;
    static getArgumentValue(value: any, componentRunner: Loader, shallow?: boolean, resourceBlacklist?: {
        [id: string]: boolean;
    }): Promise<any>;
    /**
     * @param shallow If instances should not be created.
     * @param resourceBlacklist The config resource id's to ignore in parameters. Used for avoiding infinite recursion.
     * @returns New instantiations of the provided arguments.
     */
    makeArguments(shallow?: boolean, resourceBlacklist?: {
        [id: string]: boolean;
    }): Promise<any[]>;
    /**
     * Require a package if the module that was invoked has the given module name.
     * This is done by looking for the nearest package.json.
     * @param requireName The module name that should be required.
     * @returns {any} The require() result
     * @private
     */
    _requireCurrentRunningModuleIfCurrent(requireName: string): any;
    /**
     * @param resourceBlacklist The config resource id's to ignore in parameters. Used for avoiding infinite recursion.
     * @returns A new instance of the component.
     */
    create(resourceBlacklist?: {
        [id: string]: boolean;
    }): Promise<any>;
}
