"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const N3 = require("n3");
const Path = require("path");
/**
 * A RdfStreamIncluder takes a triple stream and detects owl:includes to automatically include other files.
 */
class RdfStreamIncluder extends stream_1.PassThrough {
    constructor(constants, fromPath, followImports, absolutizeRelativePaths) {
        super({ objectMode: true });
        this._runningImporters = 1;
        this._readableState.objectMode = true;
        this._constants = constants;
        this._fromPath = fromPath;
        this._followImports = followImports;
        this._absolutizeRelativePaths = absolutizeRelativePaths;
    }
    push(data, encoding) {
        if (data) {
            if (this._followImports && data.predicate === this._constants.PREFIXES['owl'] + 'imports') {
                this._runningImporters++;
                var relativeFilePath = N3.Util.getLiteralValue(data.object);
                this._constants.getContentsFromUrlOrPath(relativeFilePath, this._fromPath)
                    .then((rawStream) => {
                    let data = this._constants.parseRdf(rawStream, null, this._fromPath, true, this._absolutizeRelativePaths);
                    data.on('data', (subData) => this.push(subData))
                        .on('error', (e) => this.emit('error', require("../Util").addFilePathToError(e, relativeFilePath, this._fromPath)))
                        .on('end', () => this.push(null));
                }).catch((e) => this.emit('error', require("../Util").addFilePathToError(e, relativeFilePath, this._fromPath)));
            }
            if (this._absolutizeRelativePaths) {
                data.subject = this._absolutize(data.subject);
                data.predicate = this._absolutize(data.predicate);
                data.object = this._absolutize(data.object);
            }
            return super.push(data);
        }
        else if (!--this._runningImporters) {
            super.push(null);
        }
    }
    _absolutize(uri) {
        // Make relative paths absolute
        var match = RdfStreamIncluder.RELATIVE_PATH_MATCHER.exec(uri);
        if (match) {
            return '"file:///' + Path.join(this._fromPath, match[1]) + '"' + this._constants.PREFIXES['xsd'] + 'string';
        }
        return uri;
    }
}
RdfStreamIncluder.RELATIVE_PATH_MATCHER = /^"file:\/\/([^\/].*)".*$/;
exports.RdfStreamIncluder = RdfStreamIncluder;
//# sourceMappingURL=RdfStreamIncluder.js.map